<?php

class wpadvert extends WP_List_Table {

    function __construct() {
        global $status, $page;
        parent::__construct(array(
            'singular' => 'wpadvert',
            'plural' => 'wpadverts',
        ));

        global $wpadvert_db_version;
        $wpadvert_db_version = "1.0";
    }

    function column_default($item, $column_name) {
        return $item[$column_name];
    }

    function column_name($item) {
        $actions = array(
            'edit' => sprintf('<a href="?page=edit_wp_advert&id=%s">%s</a>', $item['id'], __('Edit')),
            'delete' => sprintf('<a href="?page=%s&action=delete&id=%s">%s</a>', $_REQUEST['page'], $item['id'], __('Delete')),
        );

        return sprintf('%s %s', $item['name'], $this->row_actions($actions)
        );
    }

    function column_cb($item) {
        return sprintf(
                '<input type="checkbox" name="id[]" value="%s" />', $item['id']
        );
    }

    function get_columns() {
        $columns = array(
            'cb' => '<input type="checkbox" />', //Render a checkbox instead of text
            'name' => __('Name'),
            'wpadvert_message' => __('Message'),
            'wpadvert_time' => __('Created')
        );
        return $columns;
    }

    function get_sortable_columns() {
        $sortable_columns = array(
            'name' => array('name', true),
            'wpadvert_message' => array('wpadvert_message', true),
            'wpadvert_time' => array('wpadvert_time', true)
        );
        return $sortable_columns;
    }

    function get_bulk_actions() {
        $actions = array(
            'delete' => 'Delete',
        );
        return $actions;
    }

    function process_bulk_action() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'wpadvert'; // do not forget about tables prefix

        if ('delete' === $this->current_action()) {
            $ids = isset($_REQUEST['id']) ? $_REQUEST['id'] : array();
            if (is_array($ids))
                $ids = implode(',', $ids);

            if (!empty($ids)) {
                $wpdb->query("DELETE FROM $table_name WHERE id IN($ids)");
            }
        }
    }

    function prepare_items() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'wpadvert'; // do not forget about tables prefix

        $per_page = 10; // constant, how much records will be shown per page

        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        // here we configure table headers, defined in our methods
        $this->_column_headers = array($columns, $hidden, $sortable);

        // [OPTIONAL] process bulk action if any
        $this->process_bulk_action();

        // will be used in pagination settings
        $total_items = $wpdb->get_var("SELECT COUNT(id) FROM $table_name");

        // prepare query params, as usual current page, order by and order direction
        $paged = isset($_REQUEST['paged']) ? max(0, intval($_REQUEST['paged']) - 1) : 0;
        $orderby = (isset($_REQUEST['orderby']) && in_array($_REQUEST['orderby'], array_keys($this->get_sortable_columns()))) ? $_REQUEST['orderby'] : 'name';
        $order = (isset($_REQUEST['order']) && in_array($_REQUEST['order'], array('asc', 'desc'))) ? $_REQUEST['order'] : 'asc';

        // [REQUIRED] define $items array
        // notice that last argument is ARRAY_A, so we will retrieve array
        $this->items = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name ORDER BY $orderby $order LIMIT %d OFFSET %d", $per_page, $paged), ARRAY_A);

        // [REQUIRED] configure pagination
        $this->set_pagination_args(array(
            'total_items' => $total_items, // total items defined above
            'per_page' => $per_page, // per page constant defined at top of method
            'total_pages' => ceil($total_items / $per_page) // calculate pages count
        ));
    }

    function wpadvert_admin_menu() {

   
        add_menu_page('WP Advert', 'WP Advert', IC_MYPLUGIN_PERMISSIONS, "wpadvert", "ic_myplugin_settings");

        add_submenu_page('wpadvert', 'All Bars', 'All Bars', 'manage_options', 'wp_advert', 'wpadvert_bar_builder_management');

        add_submenu_page('wpadvert', 'Add New ', 'Add New', 'manage_options', 'edit_wp_advert', 'wpadvert_bar_builder_managements');

    }

    function wpadvert_db_install() {
        global $wpdb;
        global $wpadvert_db_version;
        global $table_name;
        $table_name = $wpdb->prefix . "wpadvert";

        $sql = "CREATE TABLE $table_name (
  id mediumint(9) NOT NULL AUTO_INCREMENT,
  disableinstances VARCHAR(5) NOT NULL,
  wpadvert_member VARCHAR(5) NOT NULL,
  wpadvert_visitor VARCHAR(5)NOT NULL,
  dropdown LONGTEXT NOT NULL,
  wpadvert_homepage VARCHAR(10) NOT NULL,
  wpadvert_page_id LONGTEXT NOT NULL,
  wpadvert_post_id LONGTEXT NOT NULL,
  wpadvert_message LONGTEXT NOT NULL,
  wpadvert_topbot VARCHAR(20) NOT NULL,
  wpadvert_page_load VARCHAR(20) NOT NULL,
  wpadvert_on_page_load VARCHAR(100) NOT NULL,
  wpadvert_bar_shadow VARCHAR(20) NOT NULL,
  wpadvert_bar_btn_shadow VARCHAR(20) NOT NULL,
  wpadvert_btn_bgimage VARCHAR(20) NOT NULL,
  wpadvert_bg_repeat VARCHAR(20) NOT NULL,
  wpadvert_link_text VARCHAR(1000) NOT NULL,
  wpadvert_styles VARCHAR(100) NOT NULL,
  wpadvert_background_clr VARCHAR(100) NOT NULL,
  wpadvert_background_img VARCHAR(100) NOT NULL,
  wpadvert_button_login VARCHAR(100) NOT NULL,
  wpadvert_button_register VARCHAR(100) NOT NULL,
  wpadvert_button_logout VARCHAR(100) NOT NULL,
  wpadvert_button_close VARCHAR(100) NOT NULL,
  wpadvert_disable_cookies VARCHAR(100) NOT NULL,
  wpadvert_close_cookies VARCHAR(100) NOT NULL,
  disable_message VARCHAR(100) NOT NULL,
  wpadvert_message_url VARCHAR(100) NOT NULL,
  wpadvert_break_message1 LONGTEXT NOT NULL,
  wpadvert_message2 LONGTEXT NOT NULL,
  wpadvert_message2_url LONGTEXT NOT NULL,
  wpadvert_link_text2 LONGTEXT NOT NULL,
  wpadvert_link2 LONGTEXT NOT NULL,
  wpadvert_break_message2 LONGTEXT NOT NULL,
  wpadvert_bar_height VARCHAR(100) NOT NULL,
  wpadvert_background_color VARCHAR(100) NOT NULL,
  wpadvert_background_image LONGTEXT NOT NULL,
  wpadvert_textarea_html LONGTEXT NOT NULL,
  wpadvert_textarea_css LONGTEXT NOT NULL,
  wpadvert_textarea_javascript LONGTEXT NOT NULL,
  wpadvert_link LONGTEXT NOT NULL,
  wpadvert_border_color VARCHAR(10) NOT NULL,
  wpadvert_multi_messages LONGTEXT NOT NULL,
  nbar_font_family VARCHAR(100) NOT NULL,
  nbar_font_style VARCHAR(100) NOT NULL,
  nbar_font_weight VARCHAR(100) NOT NULL,
  wpadvert_bar_redirect VARCHAR(300) NOT NULL,
  wpadvert_exclude_page_id LONGTEXT NOT NULL,
  wpadvert_exclude_post_id LONGTEXT NOT NULL,
  wpadvert_message_after_login LONGTEXT NOT NULL,
  wpadvert_multi_message_after_login LONGTEXT NOT NULL,
  wpadvert_button_expand_text VARCHAR(100) NOT NULL,
  wpadvert_button_collapse_text VARCHAR(100) NOT NULL,
  wpadvert_button_width VARCHAR(100) NOT NULL,
  wpadvert_width VARCHAR(100) NOT NULL,
  wpadvert_button_height VARCHAR(100) NOT NULL,
  wpadvert_button_position VARCHAR(100) NOT NULL,
  wpadvert_btn_pos_val VARCHAR(20) NOT NULL,
  wpadvert_expand_button_text VARCHAR(100) NOT NULL,
  wpadvert_collapse_button_text VARCHAR(100) NOT NULL,
  wpadvert_link_color VARCHAR(100) NOT NULL,
  wpadvert_link_size VARCHAR(10) NOT NULL,
  wpadvert_link_background_color VARCHAR(100) NOT NULL,
  wpadvert_animate_text_color_effect VARCHAR(100) NOT NULL,
  wpadvert_link_hover_color VARCHAR(100) NOT NULL,
  wpadvert_button_background_color VARCHAR(100) NOT NULL,
  wpadvert_message_behavior VARCHAR(100) NOT NULL,
  wpadvert_marquee_direction VARCHAR(100) NOT NULL,
  disable_wpadvert_animate_effect VARCHAR(100) NOT NULL,
  wpadvert_marquee_behavior VARCHAR(100) NOT NULL,
  wpadvert_bar_border_radius VARCHAR(100) NOT NULL,
  wpadvert_button_border_radius VARCHAR(100) NOT NULL,
  wpadvert_bar_text_effects VARCHAR(100) NOT NULL,
  wpadvert_bar_effects VARCHAR(100) NOT NULL,
  wpadvert_font_color VARCHAR(100) NOT NULL,
  wpadvert_font_size VARCHAR(100) NOT NULL,
  time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  wpadvert_time VARCHAR(190) NOT NULL,
  name VARCHAR(767) NOT NULL,
  close_button_image VARCHAR(100) NOT NULL,
  wpadvert_btn_border_color VARCHAR(100) NOT NULL,
  wpadvert_btn_font_size VARCHAR(100) NOT NULL,
  wpadvert_cookies VARCHAR(100) NOT NULL,
  wpadvert_float_padding VARCHAR(100) NOT NULL,
  wpadvert_fixed_padding VARCHAR(100) NOT NULL,
  wpadvert_btn_text VARCHAR(100) NOT NULL,
  wpadvert_style_name VARCHAR(100) NOT NULL,
  wpadvert_button_border_top LONGTEXT NOT NULL,
  wpadvert_button_border_bottom LONGTEXT NOT NULL,
  wpadvert_button_border_left LONGTEXT NOT NULL,
  wpadvert_button_border_right LONGTEXT NOT NULL,
  wpadvert_button_width_custom LONGTEXT NOT NULL,
  wpadvert_bar_height_custom LONGTEXT NOT NULL,
  wpadvert_bar_height1 LONGTEXT NOT NULL,
  wpadvert_bar_opacity LONGTEXT NOT NULL,
  wpadvert_enable_referral VARCHAR(10) NOT NULL,
  wpadvert_referral_url1 VARCHAR(100) NOT NULL,
  wpadvert_referral_message1 VARCHAR(200) NOT NULL,
    wpadvert_referral_link1 VARCHAR(100) NOT NULL,
  wpadvert_referral_url2 VARCHAR(100) NOT NULL,
  wpadvert_referral_message2 VARCHAR(200) NOT NULL,
  wpadvert_referral_link2 VARCHAR(100) NOT NULL,
  wpadvert_referral_url3 VARCHAR(100) NOT NULL,
  wpadvert_referral_message3 VARCHAR(200) NOT NULL,
  wpadvert_referral_link3 VARCHAR(100) NOT NULL,
  wpadvert_referral_url4 VARCHAR(100) NOT NULL,
  wpadvert_referral_message4 VARCHAR(200) NOT NULL,
  wpadvert_referral_link4 VARCHAR(100) NOT NULL,
  wpadvert_referral_url5 VARCHAR(100) NOT NULL,
  wpadvert_referral_message5 VARCHAR(200) NOT NULL,
  wpadvert_referral_link5 VARCHAR(100) NOT NULL,
  template VARCHAR(100) NOT NULL,
  pageid LONGTEXT NOT NULL,
  message text NOT NULL,
  wpadvert_referral_message11 LONGTEXT NOT NULL,
  wpadvert_referral_message12 LONGTEXT NOT NULL,
  wpadvert_referral_message21 LONGTEXT NOT NULL,
  wpadvert_referral_message22 LONGTEXT NOT NULL,
  wpadvert_referral_message31 LONGTEXT NOT NULL,
  wpadvert_referral_message32 LONGTEXT NOT NULL,
  wpadvert_referral_message41 LONGTEXT NOT NULL,
  wpadvert_referral_message42 LONGTEXT NOT NULL,
  wpadvert_referral_message51 LONGTEXT NOT NULL,
  wpadvert_referral_message52 LONGTEXT NOT NULL,
  wpadvert_referral_message_url11 LONGTEXT NOT NULL,
  wpadvert_referral_message_url12 LONGTEXT NOT NULL,
  wpadvert_referral_message_url21 LONGTEXT NOT NULL,
  wpadvert_referral_message_url22 LONGTEXT NOT NULL,
  wpadvert_referral_message_url31 LONGTEXT NOT NULL,
  wpadvert_referral_message_url32 LONGTEXT NOT NULL,
  wpadvert_referral_message_url41 LONGTEXT NOT NULL,
  wpadvert_referral_message_url42 LONGTEXT NOT NULL,
  wpadvert_referral_message_url51 LONGTEXT NOT NULL,
  wpadvert_referral_message_url52 LONGTEXT NOT NULL,
  wpadvert_referral_link_text11 LONGTEXT NOT NULL,
  wpadvert_referral_link_text12 LONGTEXT NOT NULL,
  wpadvert_referral_link_text21 LONGTEXT NOT NULL,
  wpadvert_referral_link_text22 LONGTEXT NOT NULL,
  wpadvert_referral_link_text31 LONGTEXT NOT NULL,
  wpadvert_referral_link_text32 LONGTEXT NOT NULL,
  wpadvert_referral_link_text41 LONGTEXT NOT NULL,
  wpadvert_referral_link_text42 LONGTEXT NOT NULL,
  wpadvert_referral_link_text51 LONGTEXT NOT NULL,
  wpadvert_referral_link_text52 LONGTEXT NOT NULL,
  wpadvert_referral_link11 LONGTEXT NOT NULL,
  wpadvert_referral_link12 LONGTEXT NOT NULL,
  wpadvert_referral_link21 LONGTEXT NOT NULL,
  wpadvert_referral_link22 LONGTEXT NOT NULL,
  wpadvert_referral_link31 LONGTEXT NOT NULL,
  wpadvert_referral_link32 LONGTEXT NOT NULL,
  wpadvert_referral_link41 LONGTEXT NOT NULL,
  wpadvert_referral_link42 LONGTEXT NOT NULL,
  wpadvert_referral_link51 LONGTEXT NOT NULL,
  wpadvert_referral_link52 LONGTEXT NOT NULL,
  wpadvert_break_referral11 LONGTEXT NOT NULL,
  wpadvert_break_referral12 LONGTEXT NOT NULL,
  wpadvert_break_referral21 LONGTEXT NOT NULL,
  wpadvert_break_referral22 LONGTEXT NOT NULL,
  wpadvert_break_referral31 LONGTEXT NOT NULL,
  wpadvert_break_referral32 LONGTEXT NOT NULL,
  wpadvert_break_referral41 LONGTEXT NOT NULL,
  wpadvert_break_referral42 LONGTEXT NOT NULL,
  wpadvert_break_referral51 LONGTEXT NOT NULL,
  wpadvert_break_referral52 LONGTEXT NOT NULL,
  UNIQUE KEY id (id)
     )DEFAULT CHARACTER SET utf8;";

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta($sql);

        add_option("wpadvert_db_version", $wpadvert_db_version);
    }

    function wpadvert_install_data() {

    }

    function wpadvert_update_db_data() {
        global $wpadvert_db_version;
        if (get_site_option('wpadvert_db_version') != $wpadvert_db_version) {
            wpadvert_install_data();
        }
    }

}

?>